==> jboss-as-clustering-jgroups-7.0.0.Final-sources.jar: org/jboss/as/clustering/jgroups/subsystem/ModelKeys.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.clustering.jgroups.subsystem;

/**
 * Constants used for model keys.
 * @author Paul Ferraro
 */
class ModelKeys {
    static final String DEFAULT_EXECUTOR = "default-executor";
    static final String DEFAULT_STACK = "default-stack";
    static final String DIAGNOSTICS_SOCKET_BINDING = "diagnostics-socket-binding";
    static final String NAME = "name";
    static final String OOB_EXECUTOR = "oob-executor";
    static final String PROPERTY = "property";
    static final String PROTOCOL = "protocol";
    static final String SOCKET_BINDING = "socket-binding";
    static final String STACK = "stack";
    static final String THREAD_FACTORY = "thread-factory";
    static final String TIMER_EXECUTOR = "timer-executor";
    static final String TRANSPORT = "transport";
    static final String TYPE = "type";
}

==> jboss-as-clustering-jgroups-7.1.0.Final-sources.jar: org/jboss/as/clustering/jgroups/subsystem/ModelKeys.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2011, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.clustering.jgroups.subsystem;

/**
 * Constants used for model keys.
 * @author Paul Ferraro
 */
class ModelKeys {
    static final String ADD_PROTOCOL = "add-protocol";
    static final String DEFAULT_EXECUTOR = "default-executor";
    static final String DEFAULT_STACK = "default-stack";
    static final String DIAGNOSTICS_SOCKET_BINDING = "diagnostics-socket-binding";
    static final String EXPORT_NATIVE_CONFIGURATION = "export-native-configuration";
    static final String MACHINE = "machine";
    static final String NAME = "name";
    static final String OOB_EXECUTOR = "oob-executor";
    static final String PROPERTY = "property";
    static final String PROPERTIES = "properties";
    static final String PROTOCOL = "protocol";
    static final String PROTOCOLS = "protocols";
    static final String RACK = "rack";
    static final String REMOVE_PROTOCOL = "remove-protocol";
    static final String SHARED = "shared";
    static final String SITE = "site";
    static final String SOCKET_BINDING = "socket-binding";
    static final String STACK = "stack";
    static final String THREAD_FACTORY = "thread-factory";
    static final String TIMER_EXECUTOR = "timer-executor";
    static final String TRANSPORT = "transport";
    static final String TRANSPORT_NAME = "TRANSPORT";
    static final String TYPE = "type";
    static final String VALUE = "value";
}
